// SierpinskiSolidsView.h : interface of the CSierpinskiSolidsView class
//
/////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_SIERPINSKISOLIDSVIEW_H__130438ED_18C7_11D5_8736_005004E2398F__INCLUDED_)
#define AFX_SIERPINSKISOLIDSVIEW_H__130438ED_18C7_11D5_8736_005004E2398F__INCLUDED_

#include "Vec3f.h"	// Added by ClassView
#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000


class CSierpinskiSolidsView : public CView
{
protected: // create from serialization only
	CSierpinskiSolidsView();
	DECLARE_DYNCREATE(CSierpinskiSolidsView)

// Attributes
public:
	CSierpinskiSolidsDoc* GetDocument();

// Operations
public:

// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CSierpinskiSolidsView)
	public:
	virtual void OnDraw(CDC* pDC);  // overridden to draw this view
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	protected:
	virtual BOOL OnPreparePrinting(CPrintInfo* pInfo);
	virtual void OnBeginPrinting(CDC* pDC, CPrintInfo* pInfo);
	virtual void OnEndPrinting(CDC* pDC, CPrintInfo* pInfo);
	//}}AFX_VIRTUAL

// Implementation
public:
	float m_RotStep;  // Constant indicating the amount to rotate if the keyboard is used for rotations.
	void Rotate_x( const float angle );  // Utility routine to rotate about the eye-space x-axis
	void Rotate_y( const float angle );  // Utility routine to rotate about the eye-space y-axis

	BOOL Reflections;  // Indicates whether reflections are shown on the ground floor.
	BOOL Shadows;      // Indicates whether shadows are cast on the ground floor.
	BOOL Spin;         // Toggles the animation mode, where the individual elements spin in-place.
	float rotAngle;    // Used with the "Spin" option. Holds the current rotational amount.

	void DrawShadows( CSierpinskiSolidsDoc* pDoc );  // Method to redraw the geometry with cast shadows.
	int MAX_Level;
	virtual ~CSierpinskiSolidsView();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif

protected:

// Generated message map functions
protected:
//objectXform[4][4];
	virtual void SierpinskiGen( Tetrahedron &tetra, int level );  // Recursive function that splits the tetra into five.
	void SierpinskiGenCube( Cube &cube1, const int level );       // Recursive function that splits the cube into 27.

	//{{AFX_MSG(CSierpinskiSolidsView)
	afx_msg void OnSize(UINT nType, int cx, int cy);
	afx_msg void OnCancelMode();
	afx_msg BOOL OnEraseBkgnd(CDC* pDC);
	afx_msg int OnCreate(LPCREATESTRUCT lpCreateStruct);
	afx_msg void OnDestroy();
	afx_msg void OnLButtonDown(UINT nFlags, CPoint point);
	afx_msg void OnLButtonUp(UINT nFlags, CPoint point);
	afx_msg void OnMouseMove(UINT nFlags, CPoint point);
	afx_msg void OnRButtonDown(UINT nFlags, CPoint point);
	afx_msg void OnRButtonUp(UINT nFlags, CPoint point);
	afx_msg void OnChar(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnSponge();
	afx_msg void OnTetra();
	afx_msg void OnResetView();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
private:
	//
	// Routines for user interaction
	//
	CPoint windowSize;  // The current window size in terms of pixels.
	Vec3f trackBallMapping( CPoint point );    // Utility routine to convert mouse locations to a virtual hemisphere
	Vec3f lastPoint;                           // Keep track of the last mouse location
	enum MovementType { ROTATE, ZOOM, NONE };  // Keep track of the current mode of interaction (which mouse button)
	MovementType Movement;                     //    Left-mouse => ROTATE, Right-mouse => ZOOM

	HGLRC m_hrc;

};

#ifndef _DEBUG  // debug version in SierpinskiSolidsView.cpp
inline CSierpinskiSolidsDoc* CSierpinskiSolidsView::GetDocument()
   { return (CSierpinskiSolidsDoc*)m_pDocument; }
#endif

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_SIERPINSKISOLIDSVIEW_H__130438ED_18C7_11D5_8736_005004E2398F__INCLUDED_)
