// Tetrahedron.cpp: implementation of the Tetrahedron class.
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "SierpinskiSolids.h"
#include "Tetrahedron.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

Tetrahedron::Tetrahedron()
{
  Pts[0] = Vec3f( -1.15, -1.0, -1.0);
  Pts[1] = Vec3f( 1.15, -1.0, -1.0);  
  Pts[2] = Vec3f( 0.0, 1.0, -1.0);  
  Pts[3] = Vec3f( 0.0, 0.0, 1.0);
  CalcMidpts();
}

Tetrahedron::~Tetrahedron()
{

}

void Tetrahedron::DrawFaces(const float rotAngle )
{
	Vec3f centroid;
	centroid = Pts[0];
	centroid += Pts[1];
	centroid += Pts[2];
	centroid += Pts[3];
	centroid *= 0.25;
	glPushMatrix();
	glTranslatef( centroid.x, centroid.y, centroid.z );
	glRotatef( rotAngle, 0.5, 1.0, 1.0 );
	glTranslatef( -centroid.x, -centroid.y, -centroid.z );

	Vec3f crossVec;
	glBegin( GL_TRIANGLES );
		//glColor3f( 1.0, 1.0, 1.0 );
		crossVec.crossProd( Pts[0], Pts[2], Pts[1] );
		glNormal3f( crossVec.x, crossVec.y, crossVec.z );
		glVertex3f( Pts[0].x, Pts[0].y, Pts[0].z );
		glVertex3f( Pts[2].x, Pts[2].y, Pts[2].z );
		glVertex3f( Pts[1].x, Pts[1].y, Pts[1].z );

		//glColor3f( 0.0, 0.0, 1.0 );
		crossVec.crossProd( Pts[0], Pts[1], Pts[3] );
		glNormal3f( crossVec.x, crossVec.y, crossVec.z );
		glVertex3f( Pts[0].x, Pts[0].y, Pts[0].z );
		glVertex3f( Pts[1].x, Pts[1].y, Pts[1].z );
		glVertex3f( Pts[3].x, Pts[3].y, Pts[3].z );

		//glColor3f( 1.0, 1.0, 0.0 );
		crossVec.crossProd( Pts[1], Pts[2], Pts[3] );
		glNormal3f( crossVec.x, crossVec.y, crossVec.z );
		glVertex3f( Pts[1].x, Pts[1].y, Pts[1].z );
		glVertex3f( Pts[2].x, Pts[2].y, Pts[2].z );
		glVertex3f( Pts[3].x, Pts[3].y, Pts[3].z );

		//glColor3f( 0.0, 1.0, 1.0 );
		crossVec.crossProd( Pts[2], Pts[0], Pts[3] );
		glNormal3f( crossVec.x, crossVec.y, crossVec.z );
		glVertex3f( Pts[2].x, Pts[2].y, Pts[2].z );
		glVertex3f( Pts[0].x, Pts[0].y, Pts[0].z );
		glVertex3f( Pts[3].x, Pts[3].y, Pts[3].z );

	  glEnd();

	  glPopMatrix();

}

Tetrahedron::Tetrahedron(Vec3f &pt1, Vec3f &pt2, Vec3f &pt3, Vec3f &pt4)
{
  Pts[0] = pt1;
  Pts[1] = pt2;
  Pts[2] = pt3;
  Pts[3] = pt4;
  CalcMidpts();
}

void Tetrahedron::CalcMidpts()
{
  mid[0] = 0.5*Pts[0] + 0.5*Pts[1];
  mid[1] = 0.5*Pts[1] + 0.5*Pts[2];
  mid[2] = 0.5*Pts[2] + 0.5*Pts[3];
  mid[3] = 0.5*Pts[3] + 0.5*Pts[0];
  mid[4] = 0.5*Pts[0] + 0.5*Pts[2];
  mid[5] = 0.5*Pts[1] + 0.5*Pts[3];
}
